import dayjs from 'dayjs';
import { WorkingTime } from '../types/schedule';

const WEEK_DAY = ['sunday', 'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday'];
const MAX_DAY_TIME = 24 * 60; // min

export const getCurrentTime = (data: WorkingTime) => {
    let startDay = data.startDayOfWeekUtc;
    let endDay = data.endDayOfWeekUtc;
    const currentTimeZone = dayjs().format('Z');
    const startUtc = data.startTimeUtc / (1000 * 1000 * 60);
    const endUtc = data.endTimeUtc / (1000 * 1000 * 60);
    const matches = currentTimeZone.match(/(\+|-)([0-9]{2}):([0-9]{2})/);
    const sign = matches[1];
    const h = matches[2];
    const m = matches[3];
    let startMin;
    let endMin;

    if (sign === '+') {
        startMin = startUtc + (Number(h) * 60) + Number(m);
        endMin = endUtc + (Number(h) * 60) + Number(m);
        // startMin = startUtc;
        // endMin = endUtc;
    }

    if (sign === '-') {
        startMin = startUtc - (Number(h) * 60) - Number(m);
        endMin = endUtc - (Number(h) * 60) - Number(m);
    }

    if (startMin > MAX_DAY_TIME) {
        startMin = startMin - MAX_DAY_TIME;
        const ind = startDay ? WEEK_DAY.indexOf(startDay) + 1 : 0;
        startDay = WEEK_DAY[ind >= WEEK_DAY.length ? 0 : ind];
    }

    if (endMin > MAX_DAY_TIME) {
        endMin = endMin - MAX_DAY_TIME;
        const ind = endDay ? WEEK_DAY.indexOf(endDay) + 1 : 0;
        endDay = WEEK_DAY[ind >= WEEK_DAY.length ? 0 : ind];
    }

    if (startMin <= 0) {
        startMin = MAX_DAY_TIME - startMin;
        const ind = startDay ? WEEK_DAY.indexOf(startDay) - 1 : 0;
        startDay = WEEK_DAY[ind < 0 ? WEEK_DAY.length - 1 : ind];
    }

    if (endMin <= 0) {
        endMin = MAX_DAY_TIME - endMin;
        const ind = endDay ? WEEK_DAY.indexOf(endDay) - 1 : 0;
        endDay = WEEK_DAY[ind < 0 ? WEEK_DAY.length - 1 : ind];
    }

    return {
        startDay,
        startTime: `${(startMin - startMin % 60)/60}:${startMin % 60 || '00'}`,
        endDay: endDay,
        endTime: `${(endMin - endMin % 60)/60}:${endMin % 60 || '00'}`
    }
};
